##############################################################################
# Description
#     This is the event handler file for generic wire edm
#
# Revisions
#
#   Date        	Who   		Reason
# 25-Oct-2001   	Oleg Chizh   	Original
# 
# $HISTORY$
#
###############################################################################

 source [MOM_ask_env_var UGII_CAM_POST_DIR]ugpost_base.tcl
# source [MOM_ask_env_var UGII_CAM_DEBUG_DIR]mom_review.tcl ;  MOM_set_debug_mode ON

         set mom_sys_program_stop_code              0
         set mom_sys_optional_stop_code             1
         set mom_sys_end_of_program_code            2
         set mom_sys_spindle_direction_code(CLW)    3
         set mom_sys_spindle_direction_code(CCLW)   4
         set mom_sys_spindle_direction_code(OFF)    5
         set mom_sys_rapid_code                     0
         set mom_sys_linear_code                    1
         set mom_sys_circle_code(CLW)               2
         set mom_sys_circle_code(CCLW)              3
         set mom_sys_delay_code(REVOLUTIONS)        4
         set mom_sys_delay_code(SECONDS)            4
         set mom_sys_cutcom_code(OFF)               40
         set mom_sys_cutcom_code(LEFT)              41
         set mom_sys_cutcom_code(RIGHT)             42
         set mom_sys_inch_code                      70
         set mom_sys_metric_code                    71
         set mom_sys_output_code(ABSOLUTE)          90
         set mom_sys_output_code(INCREMENTAL)       91
#_______________________________________________________________________________
# Kinematic Declarations
#_______________________________________________________________________________
         set mom_kin_machine_type 4_axis_wedm
         set mom_kin_4th_axis_min_incr 0.001
         set mom_kin_5th_axis_min_incr 0.001
         set mom_kin_wire_tilt_output_type COORDINATES
#_______________________________________________________________________________
# Global Variable Declaration
#_______________________________________________________________________________
         set mom_sys_list_file_columns              132
         set mom_sys_list_file_rows                     50
         set mom_sys_commentary_output          ON
         set mom_sys_list_output                          OFF
         set mom_sys_group_output                    OFF

#_______________________________________________________________________________
proc  MOM_gohome_move {} {
#_______________________________________________________________________________
	global mom_gohome_pos
	MOM_do_template gohome_move
}

#_______________________________________________________________________________
proc  MOM_wire_angles {} {
#_______________________________________________________________________________
	global mom_wire_slope
	MOM_do_template wire_angles
}

#_______________________________________________________________________________
proc  MOM_start_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the very begining of the program.
# It gets called before any command is read from the task file.
#_______________________________________________________________________________
         	global mom_part_name
         	global mom_logname
	global mom_date
	global mom_wire_cutcom_status
	unset mom_wire_cutcom_status
#********The following procedure opens the warning and listing files
	OPEN_files
#********The following procedure lists the header information in commentary data
	LIST_FILE_HEADER 

  	MOM_set_seq_off
 	MOM_output_literal "%"
  	MOM_set_seq_on
}

proc     MOM_end_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the end of the program after all
# the paths are traversed.
#_______________________________________________________________________________
         	global mom_part_name

         	MOM_do_template end_of_program

#********The following procedure lists the tool list with time in commentary data
         	LIST_FILE_TRAILER
#********The following procedure closes the warning and listing files
         	CLOSE_files
}

proc  MOM_start_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of each path in the task
# It gets called after all the general parameters of the path are loaded
# like the path name and the tool name.
#_______________________________________________________________________________

#	CHECK_OPER_TYPE
}

proc  MOM_end_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the end of a path.
#_______________________________________________________________________________

}

proc  MOM_first_move {} {
#_______________________________________________________________________________
# This procedure is executed for the initial move of each operation.  It assumes 
# the tool is moving from a safe position at rapid to the start of the operation.
#_______________________________________________________________________________
        	global mom_from_status

	if { $mom_from_status != 1 } {
		MOM_abort " FROM  .  .   FROM!"
	}
        	MOM_force once motion_g X Y
	MOM_do_template from_move
}

proc  MOM_linear_move {} {
#_______________________________________________________________________________
# This procedure is executed for each linear move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________

	MOM_do_template linear
}

proc  MOM_circular_move {} {
#_______________________________________________________________________________
# This procedure is executed for each circular move. It gets called after
# the circle data are loaded (end point and center).
#_______________________________________________________________________________

	MOM_force once motion_g X Y I J
         	MOM_do_template circle
}

proc  MOM_rapid_move {} {
#_______________________________________________________________________________
# This procedure is executed for each rapid move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________

	MOM_do_template rapid_xy
}

proc  MOM_before_output {} {
#_______________________________________________________________________________
# This procedure is executed just before a line is about to be output
# to the file. It loads the line into a variable MOM_o_buffer and then calls
# this procedure. When it returns from this procedure, the variable MOM_o_buffer
# is read and written to the file.
#_______________________________________________________________________________

}

#_______________________________________________________________________________
proc  MOM_thread_wire {} {
#_______________________________________________________________________________
        global initial_move
        set initial_move 1
}

#_______________________________________________________________________________
proc  MOM_cut_wire {} {
#_______________________________________________________________________________
}

proc  MOM_wire_cutcom {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is activated.
#_______________________________________________________________________________
	global mom_wire_cutcom_mode	
	global mom_wire_cutcom_status
	global mom_wire_cutcom_adjust_register

	if {$mom_wire_cutcom_status == "ON" } {
		set mom_wire_cutcom_status $mom_wire_cutcom_mode
             		MOM_force Once cutcom_g
         	}
	if {$mom_wire_cutcom_status == "RIGHT" || $mom_wire_cutcom_status == "LEFT" } {
             		MOM_force Once D
         	}
	MOM_do_template cutcom
}

proc  MOM_opstop {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template opstop
}

proc  MOM_stop {} {
#_______________________________________________________________________________
# This procedure is executed when the Program Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template stop
}

proc  MOM_opskip_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________
         MOM_set_line_leader always "/"
}

proc  MOM_opskip_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________
         MOM_set_line_leader off "/"
}

proc  MOM_auxfun {} {
#_______________________________________________________________________________
# This procedure is executed when the Auxiliary command is activated.
#_______________________________________________________________________________
         MOM_do_template auxiliary
}

proc  MOM_prefun {} {
#_______________________________________________________________________________
# This procedure is executed when the Preparatory function command is activated.
#_______________________________________________________________________________
         MOM_do_template preparatory
}

proc  MOM_text {} {
#_______________________________________________________________________________
# This procedure is executed when the Text command is activated.
#_______________________________________________________________________________
         global   mom_user_defined_text
         MOM_output_literal "($mom_user_defined_text)" 
}

proc  MOM_before_motion {} {
}
################################################################################
